@@ -22,9 +22,9 @@ from ask_sdk_model.directive import Directive
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Optional, Union
+    from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
-    from ask_sdk_model.interfaces.display.hint import Hint
+    from ask_sdk_model.interfaces.display.hint import Hint as Hint_5bfd483e
 
 
 class HintDirective(Directive):
@@ -46,7 +46,7 @@ class HintDirective(Directive):
     supports_multiple_types = False
 
     def __init__(self, hint=None):
-        # type: (Optional[Hint]) -> None
+        # type: (Optional[Hint_5bfd483e]) -> None
         """
 
         :param hint: 
